@@ -5,8 +5,8 @@
 # bermi a-t bermilabs - com
 # See the end of this file for the free software, open source license (BSD-style).
 
-from rules.english import English
-from rules.spanish import Spanish
+from languages.english import English
+from languages.spanish import Spanish
 
 class Inflector(object):
     """
